==> xmpp-core-common-0.8.1-sources.jar: rocks/xmpp/core/stream/StreamNegotiationResult.java <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2014-2018 Christian Schudt
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package rocks.xmpp.core.stream;

/**
 * Represents the status of the feature negotiation.
 *
 * @author Christian Schudt
 */
public enum StreamNegotiationResult {

    /**
     * The feature has been successfully negotiated.
     */
    SUCCESS,
    /**
     * The feature has been successfully negotiated and the stream now requires a restart.
     */
    RESTART,
    /**
     * The feature negotiation is incomplete, i.e. it has only been partially negotiated.
     */
    INCOMPLETE,
    /**
     * The feature will be ignored. Feature negotiation of the feature is either not initiated or aborted if it has already been started.
     */
    IGNORE
}

==> xmpp-core-common-0.9.1-sources.jar: rocks/xmpp/core/stream/StreamNegotiationResult.java <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2014-2018 Christian Schudt
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package rocks.xmpp.core.stream;

/**
 * Represents the status of the feature negotiation.
 *
 * @author Christian Schudt
 */
public enum StreamNegotiationResult {

    /**
     * The feature has been successfully negotiated.
     */
    SUCCESS,
    /**
     * The feature has been successfully negotiated and the stream now requires a restart.
     */
    RESTART,
    /**
     * The feature negotiation is incomplete, i.e. it has only been partially negotiated.
     */
    INCOMPLETE,
    /**
     * The feature will be ignored. Feature negotiation of the feature is either not initiated or aborted if it has
     * already been started.
     */
    IGNORE
}
